////////////////////////////////////////////////////////////////////////////////////////////
//
//  ========
//  Alcorn							Alcorn Control Protocols
//  ========
//  McBride							C++ Library
//  ========
//  Inc.
//  ========
//
//  The Alcorn Control Serial Class enables hardware and software developers to control 
//  Alcorn McBride Inc. Show Controllers in the Alcorn 8-Bit and Alcorn 9-Bit Protocols.  
//  
//  Both 16-bit and 32-bit versions of this class are included in this library and
//  are easily toggled for compiling by manipulating the #ifdef variable.
//
// 
///////////////////////////////////////////////////////////////////////////////////////////

// 32 BIT CODE WRITTEN BY B. Jason Crew ( Mine's Portable )
// 16 BIT CODE WRITTEN BY Jeff Long ( Mine's Faster )

///////////////////////////////////////////////////////////////////////////////////////////
// If you are compiling CAlcornControl as 32-bit, comment the line below:  
///////////////////////////////////////////////////////////////////////////////////////////

// #define WIN16	INUSE

///////////////////////////////////////////////////////////////////////////////////////////

const int EIGHTH = 0 ;
const int NINTH = 1 ;

const int INVALID = -1 ;
const int COM1 = 0 ;
const int COM2 = 1 ;
const int COM3 = 2 ;
const int COM4 = 3 ;
const int OFFLINE = 4 ;

const int COMM_ERROR = -1 ;
const int TIME_OUT = -2 ;

const int PC_ADDR = 0xFF ;
const int RBRF = 0x01 ;
const int THRE = 0x20 ; 
const int TEMT = 0x40 ;

class CAlcornControl
{
public: // routines
	CAlcornControl();
	~CAlcornControl();
	BOOL Open( UINT nNewPort = 1, UINT nNewBaudRate = 9600, UINT nNewFormat = NINTH );
	void Close( );

    void SetSource( BYTE NewSource );
	void SetTarget( BYTE NewTarget );

	BOOL SendByte( BYTE sendByte , UINT nParity = SPACEPARITY ) ; // NOT MARK
	BOOL SendMessage( CString sendMessage );

	BOOL RecvByte( UINT nTimeOut );
	BOOL RecvMessage( BYTE Buffer[] , UINT nMsgLength , UINT nTimeOut );

	int nPort;		// Current Comm Port
	UINT nBaudRate; // Current Baud Rate
	UINT nFormat;   // Current Data Bits
	DWORD dwError;	// Extended Error Information (32-bit only)
	BOOL bSuccess;	// COM read/write/open successful?

private: 
	
	void Rx();

	/////////////////////////////////////////////////////////////////////
	// Variables internal to CAlcornControl								   
	/////////////////////////////////////////////////////////////////////


	BOOL bIs9TH;	// Current Protocol Status
	DCB dcb;		// Comm Port New DCB Structure
	BYTE Source;	// Source address for 9th bit control
	BYTE Target;	// Target address for 9th bit control
	BYTE Checksum;  // Checksum of 9th bit message

#ifndef WIN16
	HANDLE hCom;	// Handle of open COM port (32-bit only)
	COMMTIMEOUTS TimeOuts; // Timeouts of port for read/write time
#else
	int ioPort;
	int ComStatus;
	int LCRData ;
	int LSRData; 
	UINT RBR;   // Receive Buffer Register
	UINT THR;   // Transmit Holding Register
    UINT LCR;	// Line Control Register
    UINT LSR;	// Line Status Register
    BOOL serialFailed ;
	COMSTAT	comStat ;
#endif
};

